summaryrefslogtreecommitdiffstats
path: root/examples/dbus/dbus-chat/chat_interface.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/dbus/dbus-chat/chat_interface.cpp')
-rw-r--r--examples/dbus/dbus-chat/chat_interface.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/dbus/dbus-chat/chat_interface.cpp b/examples/dbus/dbus-chat/chat_interface.cpp
index eb2258d5d4..01dc595ed2 100644
--- a/examples/dbus/dbus-chat/chat_interface.cpp
+++ b/examples/dbus/dbus-chat/chat_interface.cpp
@@ -50,15 +50,15 @@
#include "chat_interface.h"
/*
* Implementation of interface class ComTrolltechChatInterface
*/
-ComTrolltechChatInterface::ComTrolltechChatInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
+OrgExampleChatInterface::OrgExampleChatInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
: QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}
-ComTrolltechChatInterface::~ComTrolltechChatInterface()
+OrgExampleChatInterface::~OrgExampleChatInterface()
{
}
@@ -50,15 +50,15 @@
#include "chat_interface.h"
/*
- * Implementation of interface class ComTrolltechChatInterface
+ * Implementation of interface class OrgExampleChatInterface
*/